@@ -1,7 +1,30 @@
 def anu_pick_n_shuffle(roll_dict):
+    """Generates a roll result from a parsed roll argument vector.
+
+    Pick and Shuffle Method
+    Generate results by putting "n-balls" into a "bag" with values
+    between min and max, mix it up thoroughly, pick out a ball,
+    and record the result. Repeat this process m times.
+
+    You might notice I use ANU numbers to pick the figurative
+    balls out of the figurative bag. Doing this not only stays
+    true to the exercise found on the ANU website but
+    also produces, in my experience, more 'natural'
+    results overall.
+
+    Returns:
+    {
+        'raw': [1],
+        'modifiers': [],
+        'multiplier': '1',
+        'die': '3',
+        'rolls': [1],
+        'argv': '1d3'
+    }
+    """
+
     # TODO: Consider making this a plugin, or some form
     #   of IOC to make the shuffling method swappable.
-
     from pydie import anu
     import random
 
@@ -10,17 +33,6 @@ def anu_pick_n_shuffle(roll_dict):
     die = int(roll_dict['die'])
     modifiers = [int(x) for x in roll_dict['modifiers']]
 
-    # === Random Picks Shuffle Method ===
-    # Generate results by putting "n-balls" into a "bag" with values
-    # between min and max, mix it up thoroughly, pick out a ball,
-    # and record the result. Repeat this process m times.
-    #
-    # You might notice I use ANU numbers to pick the figurative
-    # balls out of the figurative bag. Doing this not only stays
-    # true to the exercise found on the ANU website but
-    # also produces, in my experience, more 'natural'
-    # results overall.
-
     #+1 compsensates for range min at 1
     balls = range(1, die+1)
     picks = anu.randint(min=0, max=die, length=multiplier)
